#
# spec file for package qt6-charts
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define real_version 6.4.2
%define short_version 6.4
%define short_name qtcharts
%define tar_name qtcharts-everywhere-src
%define tar_suffix %{nil}
#
%global qt6_flavor %{nil}
%if "%{qt6_flavor}" == "docs"
%define pkg_suffix -docs
%endif
#
Name:           qt6-charts%{?pkg_suffix}
Version:        6.4.2
Release:        bp155.1.7
Summary:        Qt 6 Charts library
License:        GPL-3.0-or-later
URL:            https://www.qt.io
Source:         https://download.qt.io/official_releases/qt/%{short_version}/%{real_version}%{tar_suffix}/submodules/%{tar_name}-%{real_version}%{tar_suffix}.tar.xz
Source99:       qt6-charts-rpmlintrc
BuildRequires:  pkgconfig
BuildRequires:  qt6-core-private-devel
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6OpenGL)
BuildRequires:  cmake(Qt6OpenGLWidgets)
BuildRequires:  cmake(Qt6Qml)
BuildRequires:  cmake(Qt6Quick)
BuildRequires:  cmake(Qt6QuickTest)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6Widgets)
%if "%{qt6_flavor}" == "docs"
BuildRequires:  qt6-tools
%{qt6_doc_packages}
%endif

%description
A collection of components that can be used to create charts.

%if !%{qt6_docs_flavor}

%package imports
Summary:        Qt 6 Charts QML files and plugins

%description imports
QML files and plugins from the Qt 6 Charts module.

%package -n libQt6Charts6
Summary:        Qt 6 Charts library

%description -n libQt6Charts6
The Qt 6 Charts library.

%package devel
Summary:        Qt 6 Charts library - Development files
Requires:       libQt6Charts6 = %{version}
Requires:       cmake(Qt6Gui)
Requires:       cmake(Qt6OpenGL)
Requires:       cmake(Qt6OpenGLWidgets)
Requires:       cmake(Qt6Widgets)

%description devel
Development files for the Qt 6 Charts library.

%package private-devel
Summary:        Non-ABI stable API for the Qt 6 Charts Library
Requires:       cmake(Qt6Charts) = %{real_version}

%description private-devel
This package provides private headers of libQt6Charts that do not have any
ABI or API guarantees.

%package -n libQt6ChartsQml6
Summary:        Qt 6 ChartsQml library

%description -n libQt6ChartsQml6
The Qt 6 ChartsQml library.

%package -n qt6-chartsqml-devel
Summary:        Qt 6 ChartsQml library - Development files
Requires:       libQt6ChartsQml6 = %{version}
Requires:       cmake(Qt6Charts) = %{real_version}
Requires:       cmake(Qt6OpenGL)
Requires:       cmake(Qt6Qml)
Requires:       cmake(Qt6Quick)

%description -n qt6-chartsqml-devel
Development files for the Qt 6 ChartsQml library.

%package -n qt6-chartsqml-private-devel
Summary:        Non-ABI stable API for the Qt 6 ChartsQml Library
Requires:       cmake(Qt6ChartsQml) = %{real_version}

%description -n qt6-chartsqml-private-devel
This package provides private headers of libQt6ChartsQml that do not have any
ABI or API guarantees.

%{qt6_examples_package}

%endif

%prep
%autosetup -p1 -n %{tar_name}-%{real_version}%{tar_suffix}

%build
%cmake_qt6

%{qt6_build}

%install
%{qt6_install}

%if !%{qt6_docs_flavor}

# CMake files are not needed for plugins
rm -r %{buildroot}%{_qt6_cmakedir}/Qt6Qml/QmlPlugins

%post -n libQt6Charts6 -p /sbin/ldconfig
%post -n libQt6ChartsQml6 -p /sbin/ldconfig
%postun -n libQt6Charts6 -p /sbin/ldconfig
%postun -n libQt6ChartsQml6 -p /sbin/ldconfig

%files imports
%{_qt6_qmldir}/QtCharts/

%files -n libQt6Charts6
%license LICENSES/*
%{_qt6_libdir}/libQt6Charts.so.*

%files devel
%{_qt6_cmakedir}/Qt6BuildInternals/StandaloneTests/QtChartsTestsConfig.cmake
%{_qt6_cmakedir}/Qt6Charts/
%{_qt6_descriptionsdir}/Charts.json
%{_qt6_includedir}/QtCharts/
%{_qt6_libdir}/libQt6Charts.prl
%{_qt6_libdir}/libQt6Charts.so
%{_qt6_metatypesdir}/qt6charts_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_charts.pri
%{_qt6_pkgconfigdir}/Qt6Charts.pc
%exclude %{_qt6_includedir}/QtCharts/%{real_version}

%files private-devel
%{_qt6_includedir}/QtCharts/%{real_version}
%{_qt6_mkspecsdir}/modules/qt_lib_charts_private.pri

%files -n libQt6ChartsQml6
%{_qt6_libdir}/libQt6ChartsQml.so.*

%files -n qt6-chartsqml-devel
%{_qt6_cmakedir}/Qt6ChartsQml/
%{_qt6_descriptionsdir}/ChartsQml.json
%{_qt6_includedir}/QtChartsQml/
%{_qt6_libdir}/libQt6ChartsQml.prl
%{_qt6_libdir}/libQt6ChartsQml.so
%{_qt6_metatypesdir}/qt6chartsqml_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_chartsqml.pri
%{_qt6_pkgconfigdir}/Qt6ChartsQml.pc
%exclude %{_qt6_includedir}/QtChartsQml/%{real_version}

%files -n qt6-chartsqml-private-devel
%{_qt6_includedir}/QtChartsQml/%{real_version}
%{_qt6_mkspecsdir}/modules/qt_lib_chartsqml_private.pri

%endif

%changelog
* Fri Jan  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.4.2:
  * https://www.qt.io/blog/qt-6.4.2-released
* Tue Nov 15 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.1:
  * https://www.qt.io/blog/qt-6.4.1-released
* Thu Sep 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0:
  * https://www.qt.io/blog/qt-6.4-released
* Fri Sep 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0 RC
* Fri Sep  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.2:
  * https://www.qt.io/blog/qt-6.3.2-released
* Fri Jun 17 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.1:
  * https://www.qt.io/blog/qt-6.3.1-released
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.0:
  * https://www.qt.io/blog/qt-6.3-released
* Tue Mar 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.0-rc
* Mon Mar 21 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.4
  * https://www.qt.io/blog/qt-6.2.4-released
* Mon Jan 31 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.3:
  * https://www.qt.io/blog/qt-6.2.3-released
* Wed Dec  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.2
  * https://www.qt.io/blog/qt-6.2.2-released
- Make sure all dependencies are present when installing devel
  packages. Qt >= 6.2.2 is much less permissive.
* Tue Oct 26 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.1
  * https://www.qt.io/blog/qt-6.2.1-released
* Thu Sep 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0:
  * https://www.qt.io/blog/qt-6.2-lts-released
* Sat Sep 25 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-rc2
* Thu Sep 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-rc
* Thu Sep  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-beta4
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.3:
  * https://www.qt.io/blog/qt-6.1.3-released
* Fri Jul  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.2. New bugfix release:
  * https://www.qt.io/blog/qt-6.1.2-released
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.1:
  * https://www.qt.io/blog/qt-6.1.1-released
* Thu May  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0:
  * https://www.qt.io/blog/qt-6.1-released
* Fri Apr 23 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-rc.
* Tue Apr 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-beta3.
* Fri Mar 19 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-beta2
* Thu Mar  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-beta1
  https://www.qt.io/blog/qt-6.1-beta-released
* Thu Feb 18 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-alpha:
  * https://www.qt.io/blog/qt-6.1-alpha-released
* Sat Jan 23 2021 Christophe Giboudeaux <christophe@krop.fr>
- Init qt6-charts.
